==> modeshape-sequencer-ddl-2.5.0.Final-sources.jar: org/modeshape/sequencer/ddl/DdlSequencerI18n.java <==
/*
 * ModeShape (http://www.modeshape.org)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors.
 *
 * ModeShape is free software. Unless otherwise indicated, all code in ModeShape
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * ModeShape is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.modeshape.sequencer.ddl;

import java.util.Locale;
import java.util.Set;
import org.modeshape.common.i18n.I18n;

/**
 * The internationalized string constants for the <code>org.modeshape.sequencer.ddl*</code> packages.
 */
public final class DdlSequencerI18n {

    public static I18n sequencerTaskName;
    public static I18n errorSequencingDdlContent;
    public static I18n errorParsingDdlContent;
    public static I18n unknownCreateStatement;
    public static I18n unusedTokensDiscovered;
    public static I18n unusedTokensParsingColumnsAndConstraints;
    public static I18n unusedTokensParsingColumnDefinition;
    public static I18n alterTableOptionNotFound;
    public static I18n unusedTokensParsingCreateIndex;
    public static I18n missingReturnTypeForFunction;
    public static I18n unsupportedProcedureParameterDeclaration;
    public static I18n errorInstantiatingParserForGrammarUsingDefaultClasspath;
    public static I18n errorInstantiatingParserForGrammarClasspath;

    static {
        try {
            I18n.initialize(DdlSequencerI18n.class);
        } catch (final Exception err) {
            System.err.println(err);
        }
    }

    public static Set<Locale> getLocalizationProblemLocales() {
        return I18n.getLocalizationProblemLocales(DdlSequencerI18n.class);
    }

    public static Set<String> getLocalizationProblems() {
        return I18n.getLocalizationProblems(DdlSequencerI18n.class);
    }

    public static Set<String> getLocalizationProblems( Locale locale ) {
        return I18n.getLocalizationProblems(DdlSequencerI18n.class, locale);
    }
}

==> modeshape-sequencer-ddl-4.6.1.Final-sources.jar: org/modeshape/sequencer/ddl/DdlSequencerI18n.java <==
/*
 * ModeShape (http://www.modeshape.org)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.modeshape.sequencer.ddl;

import org.modeshape.common.i18n.I18n;

/**
 * The internationalized string constants for the <code>org.modeshape.sequencer.ddl*</code> packages.
 */
public final class DdlSequencerI18n {

    public static I18n sequencerTaskName;
    public static I18n errorSequencingDdlContent;
    public static I18n errorParsingDdlContent;
    public static I18n unknownCreateStatement;
    public static I18n unusedTokensDiscovered;
    public static I18n unusedTokensParsingColumnsAndConstraints;
    public static I18n unusedTokensParsingColumnDefinition;
    public static I18n alterTableOptionNotFound;
    public static I18n unusedTokensParsingCreateIndex;
    public static I18n missingReturnTypeForFunction;
    public static I18n unsupportedProcedureParameterDeclaration;
    public static I18n errorInstantiatingParserForGrammarUsingDefaultClasspath;
    public static I18n errorInstantiatingParserForGrammarClasspath;
    public static I18n ddlNotScoredByParsers;
    public static I18n unknownParser;

    private DdlSequencerI18n() {
    }

    static {
        try {
            I18n.initialize(DdlSequencerI18n.class);
        } catch (final Exception err) {
            // CHECKSTYLE IGNORE check FOR NEXT 2 LINES
            System.err.println(err);
        }
    }
}
